# CURRENCY CONVERTER
#### THIS PACKAGE IS USED TO CONVERT INDIAN RUPEE TO USD, EURO AND YEN


## Installation 
Run the following code to install this package:
   '''cmd pip install CurrencyConvo'''

##contributer: SOWMIKA D